@@ -102,32 +102,32 @@ sub _indention {
 #
 my $space2entety = [' ','&nbsp;'];
 my @char2entity = (
-	['','&agrave;'],['','&aacute;'],['','&acirc;'],['','&auml;'],
-	['','&Agrave;'],['','&Aacute;'],['','&Acirc;'],['','&Auml;'],
-	['','&atilde;'],['','&aring;'],['','&Atilde;'],['','&Aring;'],
-	['','&aelig;'], ['','&AElig;'],['','&ccedil;'],['','&Ccedil;'],
-	['','&egrave;'],['','&eacute;'],['','&ecirc;'],['','&euml;'],
-	['','&Egrave;'],['','&Eacute;'],['','&Ecirc;'],['','&Euml;'],
-	['','&eth;'],   ['','&ETH;'],  
-	['','&igrave;'],['','&iacute;'],['','&icirc;'],['','&iuml;'], 
-	['','&Igrave;'],['','&Iacute;'],['','&Icirc;'],['','&Iuml;'], 
-	['','&micro;'], ['','&ntilde;'],['','&ntilde;'],
-	['','&ograve;'],['','&oacute;'],['','&ocirc;'],['','&ouml;'],
-	['','&Ograve;'],['','&Oacute;'],['','&Ocirc;'],['','&Ouml;'],
-	['','&otilde;'],['','&oslash;'],['','&Otilde;'],['','&Oslash;'],
-	['','&ugrave;'],['','&uacute;'],['','&ucirc;'],['','&uuml;'],
-	['','&Ugrave;'],['','&Uacute;'],['','&Ucirc;'],['','&Uuml;'],
-	['','&yacute;'],['','&Yacute;'],['','&yuml;'], 
-	['','&thorn;'], ['','&THORN;'], ['','&szlig;'],
-	['','&brvbar;'],['','&acute;'], ['','&cedil;'],['','&uml;'],
-	['','&middot;'],['','&macr;'],
-	['','&laquo;'], ['','&raquo;'], ['','&iexcl;'],['','&iquest;'],
-	['','&plusmn;'],['','&times;'], ['','&divide;'],
-	['','&not;'],   ['','&deg;'],   ['','&ordm;'], ['','&ordf;'],
-	['','&sup1;'],  ['','&sup2;'],  ['','&sup3;'],
-	['','&frac14;'],['','&frac12;'],['','&frac34;'],
-	['','&curren;'],['','&cent;'],  ['','&pound;'],['','&yen;'],
-	['','&sect;'],  ['','&para;'],  ['','&copy;'], ['','&reg;'],
+	['à','&agrave;'],['á','&aacute;'],['â','&acirc;'],['ä','&auml;'],
+	['À','&Agrave;'],['Á','&Aacute;'],['Â','&Acirc;'],['Ä','&Auml;'],
+	['ã','&atilde;'],['å','&aring;'],['Ã','&Atilde;'],['Å','&Aring;'],
+	['æ','&aelig;'], ['Æ','&AElig;'],['ç','&ccedil;'],['Ç','&Ccedil;'],
+	['è','&egrave;'],['é','&eacute;'],['ê','&ecirc;'],['ë','&euml;'],
+	['È','&Egrave;'],['É','&Eacute;'],['Ê','&Ecirc;'],['Ë','&Euml;'],
+	['ð','&eth;'],   ['Ð','&ETH;'],  
+	['ì','&igrave;'],['í','&iacute;'],['î','&icirc;'],['ï','&iuml;'], 
+	['Ì','&Igrave;'],['Í','&Iacute;'],['Î','&Icirc;'],['Ï','&Iuml;'], 
+	['µ','&micro;'], ['ñ','&ntilde;'],['Ñ','&ntilde;'],
+	['ò','&ograve;'],['ó','&oacute;'],['ô','&ocirc;'],['ö','&ouml;'],
+	['Ò','&Ograve;'],['Ó','&Oacute;'],['Ô','&Ocirc;'],['Ö','&Ouml;'],
+	['õ','&otilde;'],['ø','&oslash;'],['Õ','&Otilde;'],['Ø','&Oslash;'],
+	['ù','&ugrave;'],['ú','&uacute;'],['û','&ucirc;'],['ü','&uuml;'],
+	['Ù','&Ugrave;'],['Ú','&Uacute;'],['Û','&Ucirc;'],['Ü','&Uuml;'],
+	['ý','&yacute;'],['Ý','&Yacute;'],['ÿ','&yuml;'], 
+	['þ','&thorn;'], ['Þ','&THORN;'], ['ß','&szlig;'],
+	['Š','&brvbar;'],['Ž','&acute;'], ['ž','&cedil;'],['š','&uml;'],
+	['·','&middot;'],['¯','&macr;'],
+	['«','&laquo;'], ['»','&raquo;'], ['¡','&iexcl;'],['¿','&iquest;'],
+	['±','&plusmn;'],['×','&times;'], ['÷','&divide;'],
+	['¬','&not;'],   ['°','&deg;'],   ['º','&ordm;'], ['ª','&ordf;'],
+	['¹','&sup1;'],  ['²','&sup2;'],  ['³','&sup3;'],
+	['Œ','&frac14;'],['œ','&frac12;'],['Ÿ','&frac34;'],
+	['€','&curren;'],['¢','&cent;'],  ['£','&pound;'],['¥','&yen;'],
+	['§','&sect;'],  ['¶','&para;'],  ['©','&copy;'], ['®','&reg;'],
 );
 sub spaces2entities { _tr('fore', $space2entety) }
 sub entities2spaces { _tr('back', $space2entety) }
